# BigWord

---

---

---

---

---

`bigword` is a Python package that enables you to print words in a grid on the terminal. Words are passed as command line arguments. The grid adjusts to the terminal width, ensuring the text wraps appropriately. As words wrap to the next line, the characters take up less space to accommodate the total amount of characters per line.

## Installation

You can install `bigword` using pip:

```bash
pip install bigword
```
